"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nomad_broker_cli.api_client import ApiClient, Endpoint
from nomad_broker_cli.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from nomad_broker_cli.model.base_api_response import BaseApiResponse
from nomad_broker_cli.model.error_api_response import ErrorApiResponse
from nomad_broker_cli.model.payment_method import PaymentMethod
from nomad_broker_cli.model.payout_bill_request import PayoutBillRequest
from nomad_broker_cli.model.payout_request import PayoutRequest
from nomad_broker_cli.model.payout_response import PayoutResponse


class PayoutApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_abroad_payout(
            self,
            merchant,
            out_order_id,
            transaction_id,
            **kwargs
        ):
            """GetAbroadPayout  # noqa: E501

            Merchant query payout order infomation  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_abroad_payout(merchant, out_order_id, transaction_id, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod
                out_order_id (str): The payout number of the merchant, shall be generated by the merchant when initiating the payout request
                transaction_id (str): Payment system internal order number

            Keyword Args:
                payment_method (PaymentMethod): Must be `wechatpay` or `alipay`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PayoutResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            kwargs['out_order_id'] = \
                out_order_id
            kwargs['transaction_id'] = \
                transaction_id
            return self.call_with_http_info(**kwargs)

        self.get_abroad_payout = Endpoint(
            settings={
                'response_type': (PayoutResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payout/abroad/{merchant}',
                'operation_id': 'get_abroad_payout',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'out_order_id',
                    'transaction_id',
                    'payment_method',
                ],
                'required': [
                    'merchant',
                    'out_order_id',
                    'transaction_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'out_order_id':
                        (str,),
                    'transaction_id':
                        (str,),
                    'payment_method':
                        (PaymentMethod,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                    'out_order_id': 'out_order_id',
                    'transaction_id': 'transaction_id',
                    'payment_method': 'payment_method',
                },
                'location_map': {
                    'merchant': 'path',
                    'out_order_id': 'query',
                    'transaction_id': 'query',
                    'payment_method': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_abroad_payout
        )

        def __get_abroad_payout_bill(
            self,
            merchant,
            bill_date,
            **kwargs
        ):
            """GetAbroadPayoutBill  # noqa: E501

            Download the payout bill  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_abroad_payout_bill(merchant, bill_date, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod
                bill_date (str): Bill date. Query format YYYY-MM-DD, for example, 2021-01-01

            Keyword Args:
                merchant_id (str): Merchant ID of merchant.. [optional]
                payment_method (PaymentMethod): Must be `wechatpay` or `alipay`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                file_type
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            kwargs['bill_date'] = \
                bill_date
            return self.call_with_http_info(**kwargs)

        self.get_abroad_payout_bill = Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payout/bill/abroad/{merchant}',
                'operation_id': 'get_abroad_payout_bill',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'bill_date',
                    'merchant_id',
                    'payment_method',
                ],
                'required': [
                    'merchant',
                    'bill_date',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'bill_date':
                        (str,),
                    'merchant_id':
                        (str,),
                    'payment_method':
                        (PaymentMethod,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                    'bill_date': 'bill_date',
                    'merchant_id': 'merchant_id',
                    'payment_method': 'payment_method',
                },
                'location_map': {
                    'merchant': 'path',
                    'bill_date': 'query',
                    'merchant_id': 'query',
                    'payment_method': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_abroad_payout_bill
        )

        def __post_abroad_payout(
            self,
            merchant,
            **kwargs
        ):
            """PostAbroadPayout  # noqa: E501

            Create a payout order  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_abroad_payout(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod

            Keyword Args:
                payout_request (PayoutRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PayoutResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.post_abroad_payout = Endpoint(
            settings={
                'response_type': (PayoutResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payout/abroad/{merchant}',
                'operation_id': 'post_abroad_payout',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'payout_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'payout_request':
                        (PayoutRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'payout_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_abroad_payout
        )

        def __post_abroad_payout_bill(
            self,
            merchant,
            **kwargs
        ):
            """PostAbroadPayoutBill  # noqa: E501

            Payout funds transactions operation  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_abroad_payout_bill(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod

            Keyword Args:
                payout_bill_request (PayoutBillRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PayoutResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.post_abroad_payout_bill = Endpoint(
            settings={
                'response_type': (PayoutResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payout/bill/abroad/{merchant}',
                'operation_id': 'post_abroad_payout_bill',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'payout_bill_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'payout_bill_request':
                        (PayoutBillRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'payout_bill_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_abroad_payout_bill
        )



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.payment_api import PaymentApi  # noqa: E501


class TestPaymentApi(unittest.TestCase):
    """PaymentApi unit test stubs"""

    def setUp(self):
        self.api = PaymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_close_payment(self):
        """Test case for close_payment

        ClosePayment  # noqa: E501
        """
        pass

    def test_create_payment(self):
        """Test case for create_payment

        CreatePayment  # noqa: E501
        """
        pass

    def test_invoke_payment(self):
        """Test case for invoke_payment

        InvokePayment  # noqa: E501
        """
        pass

    def test_query_payment(self):
        """Test case for query_payment

        QueryPayment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.customs_api import CustomsApi  # noqa: E501


class TestCustomsApi(unittest.TestCase):
    """CustomsApi unit test stubs"""

    def setUp(self):
        self.api = CustomsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customs_payment(self):
        """Test case for get_customs_payment

        GetCustomsPayment  # noqa: E501
        """
        pass

    def test_post_customs_identification(self):
        """Test case for post_customs_identification

        PostCustomsIdentification  # noqa: E501
        """
        pass

    def test_post_customs_payment(self):
        """Test case for post_customs_payment

        PostCustomsPayment  # noqa: E501
        """
        pass

    def test_put_customs_payment(self):
        """Test case for put_customs_payment

        PutCustomsPayment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nomad_broker_cli
from nomad_broker_cli.model.customs_code import CustomsCode
from nomad_broker_cli.model.payment_method import PaymentMethod
globals()['CustomsCode'] = CustomsCode
globals()['PaymentMethod'] = PaymentMethod
from nomad_broker_cli.model.customs_payment_request import CustomsPaymentRequest


class TestCustomsPaymentRequest(unittest.TestCase):
    """CustomsPaymentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomsPaymentRequest(self):
        """Test CustomsPaymentRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CustomsPaymentRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.5.1"

# import ApiClient
from nomad_broker_cli.api_client import ApiClient

# import Configuration
from nomad_broker_cli.configuration import Configuration

# import exceptions
from nomad_broker_cli.exceptions import OpenApiException
from nomad_broker_cli.exceptions import ApiAttributeError
from nomad_broker_cli.exceptions import ApiTypeError
from nomad_broker_cli.exceptions import ApiValueError
from nomad_broker_cli.exceptions import ApiKeyError
from nomad_broker_cli.exceptions import ApiException



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.payout_api import PayoutApi  # noqa: E501


class TestPayoutApi(unittest.TestCase):
    """PayoutApi unit test stubs"""

    def setUp(self):
        self.api = PayoutApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_abroad_payout(self):
        """Test case for get_abroad_payout

        GetAbroadPayout  # noqa: E501
        """
        pass

    def test_get_abroad_payout_bill(self):
        """Test case for get_abroad_payout_bill

        GetAbroadPayoutBill  # noqa: E501
        """
        pass

    def test_post_abroad_payout(self):
        """Test case for post_abroad_payout

        PostAbroadPayout  # noqa: E501
        """
        pass

    def test_post_abroad_payout_bill(self):
        """Test case for post_abroad_payout_bill

        PostAbroadPayoutBill  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nomad_broker_cli.api_client import ApiClient, Endpoint
from nomad_broker_cli.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from nomad_broker_cli.model.base_api_response import BaseApiResponse
from nomad_broker_cli.model.customs_code import CustomsCode
from nomad_broker_cli.model.customs_identification_request import CustomsIdentificationRequest
from nomad_broker_cli.model.customs_identification_response import CustomsIdentificationResponse
from nomad_broker_cli.model.customs_payment_redeclare_request import CustomsPaymentRedeclareRequest
from nomad_broker_cli.model.customs_payment_request import CustomsPaymentRequest
from nomad_broker_cli.model.customs_payment_response import CustomsPaymentResponse
from nomad_broker_cli.model.customs_payments_response import CustomsPaymentsResponse
from nomad_broker_cli.model.error_api_response import ErrorApiResponse
from nomad_broker_cli.model.payment_method import PaymentMethod


class CustomsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_customs_payment(
            self,
            merchant,
            customs,
            **kwargs
        ):
            """GetCustomsPayment  # noqa: E501

            Merchant queries customs clearance information by order number  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_customs_payment(merchant, customs, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod
                customs (CustomsCode): Customs code, available options: GUANGZHOU_ZS, HANGZHOU_ZS, NINGBO, ZHENGZHOU_BS, CHONGQING, SHANGHAI_ZS, SHENZHEN, ZHENGZHOU_ZH_ZS

            Keyword Args:
                out_trade_no (str): The internal order number of the merchant system. [optional]
                transaction_id (str): Payment system internal order number. [optional]
                sub_order_no (str): The internal sub-order number of the merchant system. [optional]
                sub_order_id (str): The internal sub-order number of the payment company system. [optional]
                payment_method (PaymentMethod): Must be `wechatpay` or `alipay`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CustomsPaymentsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            kwargs['customs'] = \
                customs
            return self.call_with_http_info(**kwargs)

        self.get_customs_payment = Endpoint(
            settings={
                'response_type': (CustomsPaymentsResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/customs/payment/{merchant}',
                'operation_id': 'get_customs_payment',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'customs',
                    'out_trade_no',
                    'transaction_id',
                    'sub_order_no',
                    'sub_order_id',
                    'payment_method',
                ],
                'required': [
                    'merchant',
                    'customs',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'customs':
                        (CustomsCode,),
                    'out_trade_no':
                        (str,),
                    'transaction_id':
                        (str,),
                    'sub_order_no':
                        (str,),
                    'sub_order_id':
                        (str,),
                    'payment_method':
                        (PaymentMethod,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                    'customs': 'customs',
                    'out_trade_no': 'out_trade_no',
                    'transaction_id': 'transaction_id',
                    'sub_order_no': 'sub_order_no',
                    'sub_order_id': 'sub_order_id',
                    'payment_method': 'payment_method',
                },
                'location_map': {
                    'merchant': 'path',
                    'customs': 'query',
                    'out_trade_no': 'query',
                    'transaction_id': 'query',
                    'sub_order_no': 'query',
                    'sub_order_id': 'query',
                    'payment_method': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_customs_payment
        )

        def __post_customs_identification(
            self,
            merchant,
            **kwargs
        ):
            """PostCustomsIdentification  # noqa: E501

            Upload the payer identity information which will be re-verified by payment provider, supported payment method: wechatpay  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_customs_identification(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod

            Keyword Args:
                customs_identification_request (CustomsIdentificationRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CustomsIdentificationResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.post_customs_identification = Endpoint(
            settings={
                'response_type': (CustomsIdentificationResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/customs/identification/{merchant}',
                'operation_id': 'post_customs_identification',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'customs_identification_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'customs_identification_request':
                        (CustomsIdentificationRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'customs_identification_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_customs_identification
        )

        def __post_customs_payment(
            self,
            merchant,
            **kwargs
        ):
            """PostCustomsPayment  # noqa: E501

            Declare an payment order to the customs  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_customs_payment(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod

            Keyword Args:
                customs_payment_request (CustomsPaymentRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CustomsPaymentResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.post_customs_payment = Endpoint(
            settings={
                'response_type': (CustomsPaymentResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/customs/payment/{merchant}',
                'operation_id': 'post_customs_payment',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'customs_payment_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'customs_payment_request':
                        (CustomsPaymentRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'customs_payment_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__post_customs_payment
        )

        def __put_customs_payment(
            self,
            merchant,
            **kwargs
        ):
            """PutCustomsPayment  # noqa: E501

            Redeclare an payment order to the customs  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.put_customs_payment(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. wechat.prod

            Keyword Args:
                customs_payment_redeclare_request (CustomsPaymentRedeclareRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CustomsPaymentResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.put_customs_payment = Endpoint(
            settings={
                'response_type': (CustomsPaymentResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/customs/payment/{merchant}',
                'operation_id': 'put_customs_payment',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'customs_payment_redeclare_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'customs_payment_redeclare_request':
                        (CustomsPaymentRedeclareRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'customs_payment_redeclare_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__put_customs_payment
        )



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.profit_api import ProfitApi  # noqa: E501


class TestProfitApi(unittest.TestCase):
    """ProfitApi unit test stubs"""

    def setUp(self):
        self.api = ProfitApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_profit_receiver(self):
        """Test case for delete_profit_receiver

        DeleteProfitReceiver  # noqa: E501
        """
        pass

    def test_get_profit_sharing(self):
        """Test case for get_profit_sharing

        GetProfitSharing  # noqa: E501
        """
        pass

    def test_post_profit_receiver(self):
        """Test case for post_profit_receiver

        PostProfitReceiver  # noqa: E501
        """
        pass

    def test_post_profit_sharing(self):
        """Test case for post_profit_sharing

        PostProfitSharing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nomad_broker_cli.api_client import ApiClient, Endpoint
from nomad_broker_cli.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from nomad_broker_cli.model.base_api_response import BaseApiResponse
from nomad_broker_cli.model.error_api_response import ErrorApiResponse
from nomad_broker_cli.model.payment_close_response import PaymentCloseResponse
from nomad_broker_cli.model.payment_detail_response import PaymentDetailResponse
from nomad_broker_cli.model.payment_invocation_request import PaymentInvocationRequest
from nomad_broker_cli.model.payment_method import PaymentMethod
from nomad_broker_cli.model.payment_request import PaymentRequest
from nomad_broker_cli.model.payment_response import PaymentResponse


class PaymentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __close_payment(
            self,
            merchant,
            order_ref,
            **kwargs
        ):
            """ClosePayment  # noqa: E501

            Close a payment  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.close_payment(merchant, order_ref, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. weixinpay.test
                order_ref (str): Merchant order no.

            Keyword Args:
                payment_method (PaymentMethod): Must be `wechatpay` or `alipay`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaymentCloseResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            kwargs['order_ref'] = \
                order_ref
            return self.call_with_http_info(**kwargs)

        self.close_payment = Endpoint(
            settings={
                'response_type': (PaymentCloseResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payment/close/{merchant}/{order_ref}',
                'operation_id': 'close_payment',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'order_ref',
                    'payment_method',
                ],
                'required': [
                    'merchant',
                    'order_ref',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'order_ref':
                        (str,),
                    'payment_method':
                        (PaymentMethod,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                    'order_ref': 'order_ref',
                    'payment_method': 'payment_method',
                },
                'location_map': {
                    'merchant': 'path',
                    'order_ref': 'path',
                    'payment_method': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__close_payment
        )

        def __create_payment(
            self,
            merchant,
            **kwargs
        ):
            """CreatePayment  # noqa: E501

            Create a payment  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_payment(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. weixinpay.test

            Keyword Args:
                payment_request (PaymentRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaymentResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.create_payment = Endpoint(
            settings={
                'response_type': (PaymentResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payment/{merchant}',
                'operation_id': 'create_payment',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'payment_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'payment_request':
                        (PaymentRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'payment_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_payment
        )

        def __invoke_payment(
            self,
            merchant,
            **kwargs
        ):
            """InvokePayment  # noqa: E501

            Invoke a payment  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.invoke_payment(merchant, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. weixinpay.test

            Keyword Args:
                payment_invocation_request (PaymentInvocationRequest): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaymentResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            return self.call_with_http_info(**kwargs)

        self.invoke_payment = Endpoint(
            settings={
                'response_type': (PaymentResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payment/invocation/{merchant}',
                'operation_id': 'invoke_payment',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'payment_invocation_request',
                ],
                'required': [
                    'merchant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'payment_invocation_request':
                        (PaymentInvocationRequest,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                },
                'location_map': {
                    'merchant': 'path',
                    'payment_invocation_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__invoke_payment
        )

        def __query_payment(
            self,
            merchant,
            order_ref,
            **kwargs
        ):
            """QueryPayment  # noqa: E501

            Query a payment  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.query_payment(merchant, order_ref, async_req=True)
            >>> result = thread.get()

            Args:
                merchant (str): Merchant name to payment company, e.g. weixinpay.test
                order_ref (str): Merchant order no.

            Keyword Args:
                payment_method (PaymentMethod): Must be `wechatpay` or `alipay`. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                PaymentDetailResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['merchant'] = \
                merchant
            kwargs['order_ref'] = \
                order_ref
            return self.call_with_http_info(**kwargs)

        self.query_payment = Endpoint(
            settings={
                'response_type': (PaymentDetailResponse,),
                'auth': [
                    'authorization'
                ],
                'endpoint_path': '/payment/{merchant}',
                'operation_id': 'query_payment',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'merchant',
                    'order_ref',
                    'payment_method',
                ],
                'required': [
                    'merchant',
                    'order_ref',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'merchant':
                        (str,),
                    'order_ref':
                        (str,),
                    'payment_method':
                        (PaymentMethod,),
                },
                'attribute_map': {
                    'merchant': 'merchant',
                    'order_ref': 'order_ref',
                    'payment_method': 'payment_method',
                },
                'location_map': {
                    'merchant': 'path',
                    'order_ref': 'query',
                    'payment_method': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__query_payment
        )



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.refund_api import RefundApi  # noqa: E501


class TestRefundApi(unittest.TestCase):
    """RefundApi unit test stubs"""

    def setUp(self):
        self.api = RefundApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_refund(self):
        """Test case for create_refund

        CreateRefund  # noqa: E501
        """
        pass

    def test_query_refund(self):
        """Test case for query_refund

        QueryRefund  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nomad Broker

    Nomad payment provider aggregation, including make payments, and customs declaration for orders and etc.  # noqa: E501

    The version of the OpenAPI document: 1.5.1
    Contact: ben.song@samarkand.global
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "nomad_broker_cli"
VERSION = "1.5.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
  "nulltype",
]

setup(
    name=NAME,
    version=VERSION,
    description="Nomad Broker",
    author="OpenAPI Generator community",
    author_email="ben.song@samarkand.global",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Nomad Broker"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,

    long_description_content_type='text/markdown',
    long_description=open('README.md', encoding='utf-8').read(),
)



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from nomad_broker_cli.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from nomad_broker_cli.model.base_api_response import BaseApiResponse
from nomad_broker_cli.model.customs_code import CustomsCode
from nomad_broker_cli.model.customs_identification_request import CustomsIdentificationRequest
from nomad_broker_cli.model.customs_identification_response import CustomsIdentificationResponse
from nomad_broker_cli.model.customs_payment_order import CustomsPaymentOrder
from nomad_broker_cli.model.customs_payment_redeclare_request import CustomsPaymentRedeclareRequest
from nomad_broker_cli.model.customs_payment_request import CustomsPaymentRequest
from nomad_broker_cli.model.customs_payment_response import CustomsPaymentResponse
from nomad_broker_cli.model.customs_payments_response import CustomsPaymentsResponse
from nomad_broker_cli.model.error_api_response import ErrorApiResponse
from nomad_broker_cli.model.goods_info import GoodsInfo
from nomad_broker_cli.model.nomad_payment_callback_request import NomadPaymentCallbackRequest
from nomad_broker_cli.model.nomad_payment_callback_resource import NomadPaymentCallbackResource
from nomad_broker_cli.model.nomad_payment_request import NomadPaymentRequest
from nomad_broker_cli.model.nomad_payment_response import NomadPaymentResponse
from nomad_broker_cli.model.nomad_trade_amount import NomadTradeAmount
from nomad_broker_cli.model.nomad_trade_notification import NomadTradeNotification
from nomad_broker_cli.model.nomad_trade_response import NomadTradeResponse
from nomad_broker_cli.model.payment_close_response import PaymentCloseResponse
from nomad_broker_cli.model.payment_detail_response import PaymentDetailResponse
from nomad_broker_cli.model.payment_invocation_request import PaymentInvocationRequest
from nomad_broker_cli.model.payment_method import PaymentMethod
from nomad_broker_cli.model.payment_product import PaymentProduct
from nomad_broker_cli.model.payment_product_req import PaymentProductReq
from nomad_broker_cli.model.payment_request import PaymentRequest
from nomad_broker_cli.model.payment_response import PaymentResponse
from nomad_broker_cli.model.payment_type import PaymentType
from nomad_broker_cli.model.payout_bill_request import PayoutBillRequest
from nomad_broker_cli.model.payout_request import PayoutRequest
from nomad_broker_cli.model.payout_request_express_info import PayoutRequestExpressInfo
from nomad_broker_cli.model.payout_request_payee_info import PayoutRequestPayeeInfo
from nomad_broker_cli.model.payout_request_seller_info import PayoutRequestSellerInfo
from nomad_broker_cli.model.payout_response import PayoutResponse
from nomad_broker_cli.model.profit_receiver_request import ProfitReceiverRequest
from nomad_broker_cli.model.profit_receiver_response import ProfitReceiverResponse
from nomad_broker_cli.model.profit_sharing_receiver import ProfitSharingReceiver
from nomad_broker_cli.model.profit_sharing_receiver_base import ProfitSharingReceiverBase
from nomad_broker_cli.model.profit_sharing_receiver_req import ProfitSharingReceiverReq
from nomad_broker_cli.model.profit_sharing_request import ProfitSharingRequest
from nomad_broker_cli.model.profit_sharing_response import ProfitSharingResponse
from nomad_broker_cli.model.refund_account import RefundAccount
from nomad_broker_cli.model.refund_request import RefundRequest
from nomad_broker_cli.model.refund_response import RefundResponse
